@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 require "rails"
 require "sentry-ruby"
 require "sentry/integrable"
 require "sentry/rails/tracing"
 require "sentry/rails/configuration"
+require "sentry/rails/structured_logging"
 require "sentry/rails/engine"
 require "sentry/rails/railtie"
 
